# Gittool

Control Git config, SSH keys, and commit signing keys for multiple Git profiles.

# Command Examples

```
python main.py create b00502013@gmail.com "Jimmy Lin"
python main.py create jimmy@refl.ai
python main.py update jimmy@refl.ai --name="Jimmy"
python main.py activate b00502013@gmail
python main.py activate jimmy@refl.ai
python main.py delete b00502013@gmail.com
```
